==> prestashop_1.4.0.17.zip: prestashop/modules/statsbestcustomers/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_4f29d8c727dcf2022ac241cb96c31083'] = 'Ausgabe Aufnahmeeinstellungen leer';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_eab2b4237a7cd89c309119e35f62d168'] = 'Anzeige';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8bf8854bebe108183caeb845c7676ae4'] = 'von';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_dff4bf10409100d989495c6d5486035e'] = 'Nachname';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_04176f095283bc729f1e3926967e7034'] = 'Vorname';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'E-Mail';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_d7e637a6e9ff116de2fa89551240a94d'] = 'Besuche';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_1ff1b62d08d1195f073c6adac00f1894'] = 'ausgegebenes Geld ';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8b83489bd116cb60e2f348e9c63cd7f6'] = 'Beste Kunden';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cdc31cfb8cc370e79d854a2f82849dd2'] = 'Eine Liste der besten Kunden';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_998e4c5c80f27dec552e99dfed34889a'] = 'CSV-Export';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cb21e843b037359d0fb5b793fccf964f'] = 'Kundentreue entwickeln';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_d29468c130aa9793f3af4aeab7573dfe'] = 'Einen Kunden zu behalten ist rentabler als einen Neukunden zu akquirieren. Daher ist es notwendig, Ihre Treue zu gewinnen, oder anders gesagt, sie dazu zu bringen, zu Ihrem Webshop zurückzukehren.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_689416adced81b3cdaeda598e82aa607'] = 'Der gute Ruf ist ebenfalls ein Mittel, zufriedene Kunden zu bekommen; ein unzufriedener Kunde zieht keine Neukunden an.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_410008089d5bb723438103a84d48a59c'] = 'Um dieses Ziel zu erreichen, können Sie folgende Aktionen organisieren:';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_397a5e109a5897ee7d699050cbc93347'] = 'Punktuelle Aktionen: kommerzielle Belohnungen (benutzerdefinierte Sondernagebote, geschenkte Produkte oder Dienstleistungen), nicht-kommerzielle Belohnungen (bevorzugte Bearbeitung einer Bestellung oder eines Produkts), geldliche Belohnungen (Gutscheine, Ermäßigungsgutscheine, Payback,...).';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_4bc24eed56e0ba89fc3ab4e094d18d8a'] = 'Dauerhafte Aktionen: Treue- oder Punktekarten, die nicht nur der Kommunikation mit dem Kunden dienen, sondern ihm auch Vorteile bringen (persönliche Angebote, Rabatte).';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_2ac84f3e753fa299ebe4a6dfe57f1d9c'] = 'Diese Aktionen ermutigen Kunden zum Kauf und zu erneuten, regelmäßigen Besuchenauch in Ihrem Webshop.';

==> prestashop_1.4.2.5.zip: prestashop/modules/statsbestcustomers/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_4f29d8c727dcf2022ac241cb96c31083'] = 'Ausgabe Aufnahmeeinstellungen leer';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_eab2b4237a7cd89c309119e35f62d168'] = 'Anzeige';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8bf8854bebe108183caeb845c7676ae4'] = 'von';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_dff4bf10409100d989495c6d5486035e'] = 'Nachname';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_04176f095283bc729f1e3926967e7034'] = 'Vorname';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'E-Mail';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_d7e637a6e9ff116de2fa89551240a94d'] = 'Besuche';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_1ff1b62d08d1195f073c6adac00f1894'] = 'ausgegebenes Geld ';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8b83489bd116cb60e2f348e9c63cd7f6'] = 'Beste Kunden';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cdc31cfb8cc370e79d854a2f82849dd2'] = 'Eine Liste der besten Kunden';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_998e4c5c80f27dec552e99dfed34889a'] = 'CSV-Export';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_6602bbeb2956c035fb4cb5e844a4861b'] = 'Erklärung';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cb21e843b037359d0fb5b793fccf964f'] = 'Kundentreue entwickeln';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_d29468c130aa9793f3af4aeab7573dfe'] = 'Einen Kunden zu behalten ist rentabler als einen Neukunden zu akquirieren. Daher ist es notwendig, Ihre Treue zu gewinnen, oder anders gesagt, sie dazu zu bringen, zu Ihrem Webshop zurückzukehren.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_689416adced81b3cdaeda598e82aa607'] = 'Der gute Ruf ist ebenfalls ein Mittel, zufriedene Kunden zu bekommen; ein unzufriedener Kunde zieht keine Neukunden an.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_410008089d5bb723438103a84d48a59c'] = 'Um dieses Ziel zu erreichen, können Sie folgende Aktionen organisieren:';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_397a5e109a5897ee7d699050cbc93347'] = 'Punktuelle Aktionen: kommerzielle Belohnungen (benutzerdefinierte Sondernagebote, geschenkte Produkte oder Dienstleistungen), nicht-kommerzielle Belohnungen (bevorzugte Bearbeitung einer Bestellung oder eines Produkts), geldliche Belohnungen (Gutscheine, Ermäßigungsgutscheine, Payback,...).';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_4bc24eed56e0ba89fc3ab4e094d18d8a'] = 'Dauerhafte Aktionen: Treue- oder Punktekarten, die nicht nur der Kommunikation mit dem Kunden dienen, sondern ihm auch Vorteile bringen (persönliche Angebote, Rabatte).';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_2ac84f3e753fa299ebe4a6dfe57f1d9c'] = 'Diese Aktionen ermutigen Kunden zum Kauf und zu erneuten, regelmäßigen Besuchenauch in Ihrem Webshop.';

?>
